#!/bin/bash
. `dirname $0`"/DDR_shared_functions"

#script collects whether a AM blade is part of the license and determins its type (KASPERSKY - E1 /BIT_DEFENDER - E2).

ECHO=/bin/echo
CPPROD_UTIL=$CPDIR/bin/cpprod_util
CLISH=/bin/clish
DBGET=/bin/dbget
SED=/bin/sed
GREP=/bin/grep
AWK=/bin/awk

AM_MACRO="CPSB-EP-AM"
E2_MACRO="cpep-av-e2"

#set defaults 
ep_activated="0"
am_type="E1"
am_exist="0"

MGMT_INT=""
IP=""


SCRIPT_NAME=${0##*/}
LOG_FILE_NAME=/opt/CPInstLog/$SCRIPT_NAME.log

exec 2>> $LOG_FILE_NAME

$ECHO "Starting $SCRIPT_NAME" > $LOG_FILE_NAME

#check ep activated
$CPPROD_UTIL CPPROD_GetValue CPuepm ProdActive 1 > /dev/null 2>&1 && ep_activated="1"

if [ $? -eq 0 ]
		then			
			#check AM blade
			
			IsPolicyServer=false
			${CPDIR}/bin/cpprod_util UepmIsPolicyServer | grep 1 >> /dev/null 2>&1 && IsPolicyServer=true
				
			if [[ $IsPolicyServer == true ]]; then	
				
                                $ECHO "Policy server." >> $LOG_FILE_NAME
				GLOBAL_PROPS=${UEPMDIR}/engine/conf/global.properties
				
				if [ -f $GLOBAL_PROPS ]; then
					
					type=$($GREP 'am.type' $GLOBAL_PROPS | $AWK -F'=' '{print $2}')
				
					if [ "X$type" != "X" ]; then
						am_exist="1"
						am_type=$type						
					fi
				else					
                                        $ECHO "$GLOBAL_PROPS was not found." >> $LOG_FILE_NAME
					exit 1
				fi
			
			else			
                  	        $ECHO "Primary server." >> $LOG_FILE_NAME
			MGMT_INT=`$DBGET management:interface`
			if [ $? -ne 0 ]
			then
                                $ECHO "Failed to get management interface" >> $LOG_FILE_NAME
				exit 1
			fi 
			IP=`$CLISH -c "show interface $MGMT_INT" |grep ipv4 |awk '{print $2}'|awk -F"/" '{print$1}'`
                        	$ECHO "Machine's IP: $IP" >> $LOG_FILE_NAME
			#iterate over the licenses got from cplic by IP
			while read -r license_line ; do
				#get non-expired licences
				exp_date=`$ECHO $license_line | awk '{print $2}'`
				
				#the license is valid only if its exp_date is never or if it did not expired (i.e. it is less than the current date) 
				if [[ "$exp_date" = "never" || $(date +%s) -le $(date -d "$exp_date" +%s) ]]; then
					#check for AM blade 
					$ECHO $license_line | grep -i $AM_MACRO > /dev/null 2>&1
					if [ $? -eq 0 ]
					then
							am_exist="1"
					fi
					
					#get AM type
					$ECHO $license_line | grep -i $E2_MACRO > /dev/null 2>&1
					if [ $? -eq 0 ]
					then
						am_type="E2"					
					fi				
					
				fi
				done < <($CPDIR/bin/cplic print | grep -e $IP -e "trial")			
			fi
fi

RESULT="ep_activated=\"$ep_activated\" am_exist=\"$am_exist\" am_type=\"$am_type\""
$ECHO $RESULT
$ECHO $RESULT >> $LOG_FILE_NAME

$ECHO "Finished  $SCRIPT_NAME successfully." >> $LOG_FILE_NAME


exit 0