#!/bin/bash
. `dirname $0`"/DDR_shared_functions"

#script verifies the machine kernel version matches user given version from conditions set
#parameters received:
# 1) 'version', permitted kernel version
# 2) 'curKernelVersion' actual machine kernel version

AWK=/bin/awk
ECHO=/bin/echo

rv=0

#general error strings
error_verifying="Could not verify kernel version on the machine. More info: "
more_info=""

#parameters received are 'min_version', 'max_version', and 'curKernelVersion'
parseArgs "$@"
#check current version is only made of numbers and dots
more_info="Machine kernel version contains non numeric characters"
verifyOnlyDigits ${curKernelVersion//.} "$error_verifying$more_info"

#seperate three fields of current version
more_info="Machine kernel version not in correct format"

first_field_curVer=`$ECHO $curKernelVersion | $AWK -F'.' '{print $1}'`
verifyStringNotOnlyX "X$first_field_curVer" "$error_verifying$more_info"

second_field_curVer=`$ECHO $curKernelVersion | $AWK -F'.' '{print $2}'`
verifyStringNotOnlyX "X$second_field_curVer" "$error_verifying$more_info"

third_field_curVer=`$ECHO $curKernelVersion | $AWK -F'.' '{print $3}'`
verifyStringNotOnlyX "X$third_field_curVer" "$error_verifying$more_info"

#check max_version
if [ "X$max_version" != "X" ]
then 
	#check max_version is only digits and dots
	more_info="max_version in conditions set contains non numeric characters"
	verifyOnlyDigits ${max_version//.} "$error_verifying$more_info"
	
	#seperate three fields of version
	more_info="Max kernel version not in correct format"

	first_field_maxVer=`$ECHO $max_version | $AWK -F'.' '{print $1}'`
	verifyStringNotOnlyX "X$first_field_maxVer" "$error_verifying$more_info"

	second_field_maxVer=`$ECHO $max_version | $AWK -F'.' '{print $2}'`
	verifyStringNotOnlyX "X$second_field_maxVer" "$error_verifying$more_info"

	third_field_maxVer=`$ECHO $max_version | $AWK -F'.' '{print $3}'`
	verifyStringNotOnlyX "X$third_field_maxVer" "$error_verifying$more_info"
	
	if [ $first_field_curVer -ge $first_field_maxVer ]
	then
		if [ $first_field_curVer -gt $first_field_maxVer ]
		then
			rv=1
		else
			if [ $second_field_curVer -ge $second_field_maxVer ]
			then
				if [ $second_field_curVer -gt $second_field_maxVer ]
				then
					rv=1
				else
					if [ $third_field_curVer -gt $third_field_maxVer ]
					then
						rv=1
					fi
				fi
			fi
		fi
	fi
fi

#check min_version
if [ "X$min_version" != "X" ]
then 
	#check min_version is only digits and dots
	more_info="min_version in conditions set contains non numeric characters"
	verifyOnlyDigits ${min_version//.} "$error_verifying$more_info"
	
	#seperate three fields of version
	more_info="Min kernel version not in correct format"

	first_field_minVer=`$ECHO $min_version | $AWK -F'.' '{print $1}'`
	verifyStringNotOnlyX "X$first_field_minVer" "$error_verifying$more_info"

	second_field_minVer=`$ECHO $min_version | $AWK -F'.' '{print $2}'`
	verifyStringNotOnlyX "X$second_field_minVer" "$error_verifying$more_info"

	third_field_minVer=`$ECHO $min_version | $AWK -F'.' '{print $3}'`
	verifyStringNotOnlyX "X$third_field_minVer" "$error_verifying$more_info"
	
	if [ $first_field_curVer -le $first_field_minVer ]
	then
		if [ $first_field_curVer -lt $first_field_minVer ]
		then
			rv=1
		else
			if [ $second_field_curVer -le $second_field_minVer ]
			then
				if [ $second_field_curVer -lt $second_field_minVer ]
				then
					rv=1
				else
					if [ $third_field_curVer -lt $third_field_minVer ]
					then
						rv=1
					fi
				fi
			fi
		fi
	fi
fi

endCheck $rv "Machine's kernel version is $curKernelVersion"