#!/bin/bash
. `dirname $0`"/DDR_shared_functions"

#script verifies there is enough memory on the machine
#parameters received:
# 1) 'required_total_mem', user defined required memory in conditions set. This can be given in bytes,kilobytes,megabytes,or gigabytes
# 2) 'required_free_mem', user defined required memory in conditions set. This can be given in bytes,kilobytes,megabytes,or gigabytes
# 3) 'total_mem' amount of total memory, received from collect
# 4) 'free_mem' amount of free memory, received from collect

# This function split the given argument into $required_amount in bytes and $size_units
function splitToSizeAndUnits()
{
	error_verifying="'$1' is a memory size string" # getUnitsFromString() needs this var for in case of error

	#translate $1 depending on the given unit
	getUnitsFromString $1 				#function defines 'size_units'
	convertSizeToBytes $1 $size_units 	#function defines 'required_amount'
}

# This function sets $rv to 1 if $1 less than $2, otherwise it does nothing
function checkSizeRequirements()
{
	if [ $1 -lt $2 ]
	then
			rv=1
	fi
}

function appendExitMessage()
{
	if [ "$1" != "0" ]
	then
		exitMessage=$exitMessage"There are `displaySpaceToUser $2 $3` of total memory available on your machine (required $1). "
	fi
}

rv=0

#parameters received are 'required_total_mem', 'required_free_mem' 'total_mem' and 'free_mem'
parseArgs "$@"
internal_err_str="Internal error: Failed to check memory requirements."

#units user used to describe free memory needed
size_units=""

#-------------------------
#MAIN
#-------------------------


if [ "X$total_mem" = "X" ]
then
	endCheck 1 "$internal_err_str"
fi

if [ "X$free_mem" = "X" ]
then
	endCheck 1 "$internal_err_str"
fi

if [ "X$required_total_mem" = "X" ]
then
	required_total_mem="0"
fi

if [ "X$required_free_mem" = "X" ]
then
	required_free_mem="0"
fi

if [ "$required_total_mem" = "0" ] && [ "$required_free_mem" = "0" ]
then
	endCheck 1 "$internal_err_str"
fi

#convert collect result to bytes
total_mem_in_bytes=$((total_mem * (2**10)))
free_mem_in_bytes=$((free_mem * (2**10)))

splitToSizeAndUnits $required_total_mem 
required_total_mem_bytes=$required_amount
required_total_mem_units=$size_units

splitToSizeAndUnits $required_free_mem
required_free_mem_bytes=$required_amount
required_free_mem_units=$size_units

checkSizeRequirements $total_mem_in_bytes $required_total_mem_bytes
checkSizeRequirements $free_mem_in_bytes $required_free_mem_bytes


appendExitMessage $required_total_mem $required_total_mem_units $total_mem_in_bytes
appendExitMessage $required_free_mem $required_free_mem_units $free_mem_in_bytes

endCheck $rv "$exitMessage"