#!/bin/bash
. `dirname $0`"/DDR_shared_functions"

#script verifies  UpgradeTools build installed
#parameters received:
# 1) 'max_build', user defined max UpgradeTools build in conitions set
# 2) 'min_build' user defined min UpgradeTools build in conitions set
# 3) 'upgradeToolsBuild' received from collect

ECHO=/bin/echo
CPPROD_UTIL=$CPDIR/bin/cpprod_util
SED=/bin/sed
CAT=/bin/cat
PS=/bin/ps
rv=0

IsMgmt=`$CPPROD_UTIL FwIsFirewallMgmt`
if [ ${IsMgmt} != 1 ]; then 
	endCheck $rv "Upgrade Tools package is not applicable on this machine"
fi 

ver=`$CPPROD_UTIL CPPROD_GetVerText CPshared|$SED "s/ //g"`
releaseVer=`$CPPROD_UTIL CPPROD_GetValue FW1 CurrentMgmtReleaseVersion 1 2>/dev/null`

#make sure we receive the full output of ps commands 
COLUMNS=300

#find the path to conditions_set_is_ngm_upgrade.json
ppid=$($CAT /proc/$$/stat | $CUT -f4 -d\  )
gppid=$($CAT /proc/$ppid/stat | $CUT -f4 -d\  )
gppidArgs=$($PS -o args= -p $ppid)
metadataPathArg=$($ECHO $gppidArgs | $CUT -f3 -d\ | $SED "s/--path_to_metadata=//" )
jsonDirPath=$(dirname "$metadataPathArg" )

#run DDR to determine whether we are using ngm upgrade or old upgrade
/opt/DDR/bin/DDRService --action=collect_and_verify --path_to_metadata=${jsonDirPath}/conditions_set_is_ngm_upgrade.json --output_file=/tmp/DDR_validation_$$ 2>/dev/null
is_ngm_upgrade=$?

#run verfy upgrade tools only for ngm_upgrade
if  [ $is_ngm_upgrade -ne 0 ]; then
	endCheck $rv "Upgrade Tools package is not applicable for this version"
fi

error_message=$'Your Upgrade Tools package is not up-to-date or failed to be retrieved automatically. To download the package manually, refer to sk135172.'
sucess_message=$'Your upgrade tools package is up-to-date'

#parameters received are 'max_build', 'min_build', and 'upgradeToolsBuild'
parseArgs "$@"

if [ "X$upgradeToolsBuild" == "XFailed to find the value" ]; then
	rv=1
	endCheck $rv "$error_message"
fi 

verifyOnlyDigits $upgradeToolsBuild "$error_message"

#check max_build
if [ "X$max_build" != "X" ]
then 
	#check max_build is only digits
	verifyOnlyDigits $max_build "$error_message"
	
	if [ $upgradeToolsBuild -gt $max_build ]
	then
		rv=1
	fi
fi

#check min build
if [ "X$min_build" != "X" ] 
then 
	#check min_build is only digits
	verifyOnlyDigits $min_build "$error_message"
	
	if [ $upgradeToolsBuild -lt $min_build ]
	then
		rv=1
	fi
fi

if [ $rv -eq 1 ];
then
	message=$error_message
else
	message=$sucess_message
fi
endCheck $rv "$message"
