#!/bin/sh

#######################################
# Should be called only on Provider-1 environment
#######################################

VerifyPluginPreUninstall()
{
	PI_NAME=$1
	AUTO_DEACTIVATE=$2

	if [ "X$PI_NAME" = "X" ]; then
	    $ECHO "Error empty 'plugin name'";
	    FUNCTION_RES=1
	    return
	fi

	REG_NAME=$PI_NAME

	CP_VER=`$CPDIR/bin/cpprod_util CPPROD_GetCurrentVersion $PI_NAME | $SED 's/ //g'` 
	
	if [ "X$CP_VER" = "X" -o "X$CP_VER" = "X<nil>" ]; then
		$ECHO "Error: Failed to detect CPVER from registry";
		FUNCTION_RES=1
		return
	fi
	
	ENV_NAME=`$CPDIR/bin/cpprod_util CPPROD_GetValue $PI_NAME//$CP_VER ENV_NAME 1`
	PIBSDIR=`$CPDIR/bin/cpprod_util CPPROD_GetValue $PI_NAME//$CP_VER $ENV_NAME 1`
	

	# Run plugin_preuninstall_verifier
	$ECHO "Running plugin_preuninstall_verifier for Plug-in $PI_NAME" >> $USERLOG
	$ECHO "\nRunning plugin_preuninstall_verifier for Plug-in $PI_NAME..."
	
	$PIBSDIR/bin/uacRunner -p $PI_NAME -preuninstall  >> $USERLOG 2>&1
	if [ $? -ne 0 ] ; then
		if [ "$AUTO_DEACTIVATE" = "-auto_deactivate" ]; then
			# Run deactivate
			$ECHO "Running deactivate for Plug-in $PI_NAME..."
			$ECHO "Running deactivate  for Plug-in $PI_NAME" >> $USERLOG
			mdscmd deactivateplugin $PI_NAME -all  >> $USERLOG 2>&1
			if [ $? -ne 0 ] ; then
				$ECHO "Deactivate for Plug-in $PI_NAME has failed"
				$ECHO "Deactivate for Plug-in $PI_NAME has failed" >> $USERLOG
				FUNCTION_RES=1
				return
			else
				FUNCTION_RES=0
				return
			fi
			
		else
			FUNCTION_RES=1
			return
		fi
	fi
	FUNCTION_RES=0
	return
}
 

################################################
CheckPluginsPreuninstall()
{
	
		$ECHO "=======================================================" >> $USERLOG 2>&1
		$ECHO "=======================================================" >> $USERLOG
		$ECHO "`date`"  >> $USERLOG 2>&1
		
		PREUNINSTALL_PIS=`$CPDIR/bin/cpprod_util CPPROD_GetInstalledPlugIns`
		if [ "X$PREUNINSTALL_PIS" = "X" ]; then
			$ECHO "No Plug-ins found. Check is irrelevant."
			return 0
		fi
		
		LAST_MINOR_VERSION=`$CPDIR/bin/cpprod_util CPPROD_GetLastMinorVersion  | $SED 's/ //g'`
		if [ "X$LAST_MINOR_VERSION" = "X" ]; then
			$ECHO "Error: Failed to detect LAST_MINOR_VERSION from registry"
			$ECHO "Error: Failed to detect LAST_MINOR_VERSION from registry" >> $USERLOG
			return 1
		fi


		$ECHO "The minor version is $LAST_MINOR_VERSION" >> $USERLOG

		for PLUGIN_NAME in $PREUNINSTALL_PIS
		do
			
			PLG_MINOR_VERSION=`$CPDIR/bin/cpprod_util CPPROD_GetValue $PLUGIN_NAME MinorVersion 1  | $SED 's/ //g'`
			if [ "X$PLG_MINOR_VERSION" = "X" ]; then
				$ECHO "Error: Failed to detect PLG_MINOR_VERSION from registry"
				$ECHO "Error: Failed to detect PLG_MINOR_VERSION from registry" >> $USERLOG
				return 1
			fi


			if [ "X$PLG_MINOR_VERSION" = "X$LAST_MINOR_VERSION" ]; then
				VerifyPluginPreUninstall $PLUGIN_NAME $1
				if [ $FUNCTION_RES -ne 0 ]; then
					PREUNINSTALL_FAILED_PIS="$PREUNINSTALL_FAILED_PIS $PLUGIN_NAME"
				fi
				$ECHO "=======================================================" >> $USERLOG
			fi
		done
		
		$ECHO ""
		if [ "X$PREUNINSTALL_FAILED_PIS" != "X" ]; then
				$ECHO "Aborting! Pre-uninstall Verifier failed for the following Plug-in/s: $PREUNINSTALL_FAILED_PIS." >> $USERLOG 2>&1
				
				$ECHO "\nAborting! Pre-uninstall Verifier failed for the following Plug-in/s: $PREUNINSTALL_FAILED_PIS."
				$ECHO "Please connect to MDG and deactivate all the activated domains."
			return 1
		else 
			$ECHO "Pre-uninstall Verifier succeeded!"
			return 0
		fi
		
}



#####################################
#MAIN - Code Starts Here
#####################################

##Initialization
SCRIPT_NAME="CheckIfMdsUninstallIsAllowed"
LOGFILE="/opt/CPInstLog/MiniWrapper.elg"
USERLOG="$MDSDIR/log/preuninstall.elg"
ECHO=/bin/echo
FAIL_CMAS=""
PREUNINSTALL_FAILED_PIS=""


##Verify essential environment vars
if [ "X$MDS_SYSTEM" = "X" ] ; then
	ERR_MSG="$SCRIPT_NAME : Error! MDS_SYSTEM environment variable not defined, aborting."
	$ECHO "$ERR_MSG" >>$LOGFILE
	$ECHO "$ERR_MSG"  >>$USERLOG
	$ECHO "$ERR_MSG" 
	exit 1
fi

if [ "X$MDS_CPDIR" = "X" ] ; then
	ERR_MSG="$SCRIPT_NAME : Error! MDS_CPDIR environment variable not defined, aborting."
	$ECHO "$ERR_MSG"  >> $LOGFILE
	$ECHO "$ERR_MSG"  >>$USERLOG
	$ECHO "$ERR_MSG" 
	exit 1
fi

if [ "X$MDSDIR" != "X$FWDIR" ] ; then
	ERR_MSG="$SCRIPT_NAME : Error! Should run this command in Multi Domain Server environment, aborting."
	$ECHO "$ERR_MSG"  >> $LOGFILE
	$ECHO "$ERR_MSG"  >>$USERLOG
	$ECHO "$ERR_MSG" 
	exit 1

fi

##Include basic scripts
. $MDS_CPDIR/tmp/.CPprofile.sh
. $MDS_SYSTEM/shared/OSdependency.sh



##Header
$ECHO "Verifying uninstall environment for MDS...\c"

CheckPluginsPreuninstall $1
if [ $? -ne 0 ]; then
	exit 1
fi


$ECHO "Done!"

exit 0
