#!/bin/bash

#array for saving all available products
Products=()
Blocking_Minors=()
PLUGIN_REG_MARK="PIOfficialName"
LOG_FILE="/opt/CPInstLog/R77.30_install_plugin_check.log"

#current minor version installed
Minor_version_installed="R77.30"

#get all installed products from the registry and save them to Products array
function get_installed_products {
	for prod in `cpprod_util CPPROD_GetInstalledProducts`
		do Products=("${Products[@]}" "$prod")
	done
}

function print_Blocking_Minors {
	#print the content to the screen as well as to the log file
	Message="Before uninstalling $Minor_version_installed, uninstall the following plugins:"
	DB_Message="$Message"
	first=1
	
	for plugin in "${Blocking_Minors[@]}" 
	do
		Message="$Message
$plugin"
		if [ $first -eq 1 ]
		then
			DB_Message="$DB_Message $plugin"
			first=0
		else
			DB_Message="$DB_Message, $plugin"
		fi
	done
	
	echo -e $Message 
	echo -e $Message > $LOG_FILE
	
	if [ -f /etc/appliance_config.xml ]
	# Only for Gaia - add the error reason to the DB binding
	then
		/bin/dbset installer:hook_error "$DB_Message"
	fi
}
		   
#checks for each products if its a plugin, if no removes it from the Products array
function check_plugin {
	for prod in "${Products[@]}" 
	do 
		PLUGIN_NAME=$(cpprod_util CPPROD_GetValue $prod $PLUGIN_REG_MARK 1 2>/dev/null)
		if [ "$?" == "0" ]
		then
			#the product is a plugin - save the value (the plugin official name) 
			RelatedVersion=$(cpprod_util CPPROD_GetValue $prod RelatedVersion 1 2>/dev/null)
			if [ "X$RelatedVersion" == "X$Minor_version_installed" ]
			then
				#add this plugin name to the Blocking_Minors array 
				Blocking_Minors=("${Blocking_Minors[@]}" "$PLUGIN_NAME")
			fi
		fi
	done
}
		   
#step 1 - find all installed products on the current machine and append them to Products
get_installed_products

#step 2 - for each product check if its plugin, if plugin check if installed on current version, if so then save the plugin name
check_plugin

if [ ${#Blocking_Minors[@]} -gt 0 ]
then
	print_Blocking_Minors
	exit 1
fi
exit 0

