#!/bin/bash

source /etc/profile.d/vsenv.sh

#-------------- GLOBALS ----------------------#

#PREVIOUS_MINOR_VERSION values:
#1. <nil> - No previous version is avilable, no HFA was installed.
#2. 0 - Going back to Major version for example R77
#3. R77.XX - Going back to R77.XX
PREVIOUS_MINOR_VERSION=`cpprod_util CPPROD_GetPrevMinorVersion | sed 's/ //g'`

MKDIR="/bin/mkdir -p"
LN="/bin/ln"
CP="/bin/cp -r"
SED="/bin/sed"
TOUCH="/bin/touch"
RM="/bin/rm"
DIFF="/usr/bin/diff"
MV="/bin/mv"
GREP="/bin/grep"
CHMOD="/bin/chmod"
CAT="/bin/cat"
TAR="/bin/tar"
DATE="/bin/date"
ECHO="/bin/echo"


CVPN_LOG_FILE="/dev/null"
if [ -d /opt/CPInstLog/ ]; then
	CVPN_LOG_FILE="/opt/CPInstLog/uninstall_cvpn_HOTFIX_HOOK.elg"
fi

echo_debug()
{
	echo "post_uninstall_cvpn.sh: $@" >> $CVPN_LOG_FILE
}

cp_d()
{	
	local ECHO_D="echo_debug cp_d: "
	
	local cp_cmd=$@
	
	$ECHO_D "$CP $cp_cmd"
	$CP $cp_cmd
	
	return $?
}

mv_d()
{	
	local ECHO_D="echo_debug mv_d: "
	
	local cmd=$@
	
	$ECHO_D "$MV $cmd"
	$MV $cmd
	
	return $?
}

update_vses()
{
	local ECHO_D="echo_debug update_vses: "
	
	if [ `$CPDIR/bin/cpprod_util FwIsVSX` -ne 1 ]; then
		$ECHO_D "This is not a VSX environment"
		return 0
	fi
	

	$ECHO_D "This is a VSX environment. Update all VSes.."
	
	OLD_CVPNDIR=$CVPNDIR
	echo_debug "old cvpndir: $OLD_CVPNDIR"

	# Iterate all VSes
	for curr_vs_id in {1..512} 
	do 
		vsenv $curr_vs_id >& /dev/null
	
		if [ $? -eq 0 ]; then			
			
			echo_debug "Updating vs: $curr_vs_id "
			
			echo_debug "Copying new files.. "
			copy_new_files $OLD_CVPNDIR $CVPNDIR
			echo_debug "Done updating VS: $curr_vs_id "
		fi	
	done
	
	vsenv 0 >& /dev/null
}

restore_template()
{
	local ECHO_D="echo_debug restore_template: "

	if [ -f $CVPNDIR/templateBackup$PREVIOUS_MINOR_VERSION.tar.gz ]; then
		$ECHO_D "Restore old template folder"
		$RM -rf $CVPNDIR/template/
		$TAR -xzf $CVPNDIR/templateBackup$PREVIOUS_MINOR_VERSION.tar.gz -C $CVPNDIR/ >> $CVPN_LOG_FILE
		$RM -f $CVPNDIR/templateBackup$PREVIOUS_MINOR_VERSION.tar.gz
	else
		$ECHO_D "Copy template folders"
		cp_d $CVPNDIR/conf				$CVPNDIR/template
		cp_d $CVPNDIR/htdocs 			$CVPNDIR/template
		cp_d $CVPNDIR/phpincs 			$CVPNDIR/template
		cp_d -p $CVPNDIR/var 			$CVPNDIR/template
		
		$ECHO_D "Delete SNX and ICS files from template"
		$RM $CVPNDIR/template/htdocs/SNX/CSHELL/*
		$RM $CVPNDIR/template/htdocs/SNX/INSTALL/*
		$RM $CVPNDIR/template/htdocs/ICS/components/*
		
		$ECHO_D "Delete UserSettings from template"
		$RM $CVPNDIR/template/var/db/UserSettings.sql
	
	fi
	return 0
}


delete_user_settings()
{
	local ECHO_D="echo_debug delete_user_settings: "
	

	$ECHO_D "UserSettings.sql was renamed to UserSettings_upgrade_backup.sql. A new UserSettings database will be created on cvpn boot"
	cp_d $CVPNDIR/var/db/UserSettings.sql $CVPNDIR/var/db/UserSettings_upgrade_backup.sql
	$RM $CVPNDIR/var/db/UserSettings.sql
			
	return 0
}

update_vs()
{
	local ECHO_D="echo_debug update_vs: "
	
	local OLD_CVPNDIR=$1
	local NEW_CVPNDIR=$2
	
	$ECHO_D "old_cvpndir: $OLD_CVPNDIR, new_cvpndir: $NEW_CVPNDIR"
	
	$ECHO_D "delet user settings database"
	delete_user_settings
	
	$ECHO_D "Backup cvpnd.C"
	mv_d $NEW_CVPNDIR/conf/cvpnd.C $NEW_CVPNDIR/conf/cvpnd.C.orig
	
	$ECHO_D "Copy folders from template"
	
	cp_d 	$OLD_CVPNDIR/template/conf 			$NEW_CVPNDIR
	cp_d -p $OLD_CVPNDIR/template/var 			$NEW_CVPNDIR
	cp_d 	$OLD_CVPNDIR/template/phpincs 		$NEW_CVPNDIR
	cp_d 	$OLD_CVPNDIR/template/htdocs 		$NEW_CVPNDIR
	
	$ECHO_D "Restoring cvpnd.C"
	mv_d $NEW_CVPNDIR/conf/cvpnd.C.orig $NEW_CVPNDIR/conf/cvpnd.C
	
	if [ ! -x $CVPNDIR/scripts/cvpn_post_utility.csh ] ; then
		$ECHO_D "cvpn_post_utility.csh not executable"
		return 2
	fi
	
	$ECHO_D "Calling cvpn_post_utility.csh"
	$CVPNDIR/scripts/cvpn_post_utility.csh >> $CVPN_LOG_FILE
	
	return 0
}


update_all_vses()
{
	local ECHO_D="echo_debug update_all_vses: "
	
	local OLD_CVPNDIR=$CVPNDIR
	
	$ECHO_D "restore template files"
	restore_template 

	# Calling cvpn_post_utility.csh for VS0 and non-VSX gateway
	$ECHO_D "Calling cvpn_post_utility.csh"
	$CVPNDIR/scripts/cvpn_post_utility.csh >> $CVPN_LOG_FILE
	
	if [ `$CPDIR/bin/cpprod_util FwIsVSX` -ne 1 ] ; then
		echo_debug "This is not a VS environment"
		return 0
	fi

	if [ -f $CVPNDIR/scripts/custom_pre_vsx_uninstall ]; then
		$CHMOD a+x $CVPNDIR/scripts/custom_pre_vsx_uninstall
		$CVPNDIR/scripts/custom_pre_vsx_uninstall >> $CVPN_LOG_FILE
	fi

	$ECHO_D  "Iterating over all VSes"
	
	# Iterate all VSes
	for curr_vs_id in {1..512} 
	do 
		vsenv $curr_vs_id >> $CVPN_LOG_FILE
	
		if [ $? -eq 0 ]; then			
			
			$ECHO_D "Updating vs: $curr_vs_id "
			update_vs $OLD_CVPNDIR $CVPNDIR
			
			$ECHO_D "Done updating vs: $curr_vs_id "
		fi	
	done
	vsenv 0 >> $CVPN_LOG_FILE
	
	if [ -f $CVPNDIR/scripts/custom_post_vsx_uninstall ]; then
		$CHMOD a+x $CVPNDIR/scripts/custom_post_vsx_uninstall
		$CVPNDIR/scripts/custom_post_vsx_uninstall >> $CVPN_LOG_FILE
	fi

	return 0
}

#-------------- MAIN ----------------------#

if [ "x$CVPNDIR" == "x" ] ; then
	echo_debug "No CVPNDIR. No need to run."
	exit 1
fi

echo_debug "Begin"

# Restroing macro convention in R77
if [ $PREVIOUS_MINOR_VERSION == "0" ]; then
	echo_debug "Reverting to major, updating cvpnd.c"
    $SED -i s^'$CVPNDIR'^__CVPNDIR__^g $CVPNDIR/conf/cvpnd.C
fi

# Update all VSes (Including VS0)
update_all_vses

echo_debug "Done"

exit 0

