#!/bin/bash

source /etc/profile.d/vsenv.sh

# If the $CVPNDIR enviroment variable is undefined, then the pre-installation tasks aren't required.
# This happens in R71.30 when the 'cvpn' package is installed from scratch, and the R71.30 package is installed right after 
# the R71 package, without a reboot in between.
#
if [ "x$CVPNDIR" == "x" ] ; then
        exit 0
fi

# We must recode the persistent DB of cvpnd
recode_db()
{
	echo_debug "running recode DB for $CVPNDIR"
	if [ -x $CVPNDIR/bin/RecodeDB ] ; then
			echo_debug "starting recode DB for $CVPNDIR"
			$CVPNDIR/bin/RecodeDB /opt/CPInstLog/RecodeDB_MiniWrapper.elg $CVPNDIR/conf/dbwriter.C

			if [ $? != 0 ]; then
					cp $CVPNDIR/var/db/UserSettings.sql $CVPNDIR/var/db/UserSettings_upgrade_backup.sql
					rm $CVPNDIR/var/db/UserSettings.sql
					echo_debug "Error during RecodeDB execution. UserSettings.sql was renamed to UserSettings_upgrade_backup.sql. A new UserSettings database will be created on cvpn boot"
			fi
			echo_debug "Recode DB done."
	fi
}

echo_debug()
{
	echo "pre_install_all_vses: $@" >> /opt/CPInstLog/RecodeDB_MiniWrapper.elg
}
#this is required for VS 0 or for non VSX enviorment
recode_db

# Update all VSes
if [ `$CPDIR/bin/cpprod_util FwIsVSX` -eq 1 ] ; then
	echo_debug "This is a VSX environment. Update all VSes.."

	# Iterate all VSes
	for curr_vs_id in {1..512} 
	do 
		echo_debug "about to run on enviorment Id $curr_vs_id"
		vsenv $curr_vs_id 2>&1 1>/dev/null
		if [ $? -eq 0 ]; then
			
			echo_debug "Updating vs: $curr_vs_id "
			
			echo_debug "Recoding DB for all vses"
			recode_db
			echo_debug "Done updating VS: $curr_vs_id "
		fi	
	done
	echo_debug "finsihed updating all vses"
	vsenv 0 2>&1 1>/dev/null
else
	echo_debug "This is not a VS environemnt"
fi

exit 0
